@@ -176,10 +176,10 @@ class BaseTest(unittest.TestCase):
             window.child(roleName="text", label="Encryption password").text = password
             window.child(roleName="text", label="Confirm password").text = password
             if remember:
-                window.child(roleName="check box", name="Remember password").click()
+                window.child(roleName="switch", name="Remember password").click()
         else:
             window.child(
-                roleName="check box", name="Password-protect your backup"
+                roleName="switch", name="Password-protect your backup"
             ).click()
 
         window.button("Continue").click()
