@@ -23,10 +23,6 @@ class PreferencesTest(BaseTest):
 
         self.app = self.cmd()
 
-    def get_auto_check(self, root):
-        box = root.child(roleName="list item", name="Back Up Automatically")
-        return box.child(roleName="check box")
-
     def get_preferences_window(self):
         return self.get_dialog(self.app)
 
@@ -34,7 +30,7 @@ class PreferencesTest(BaseTest):
         self.app.child(roleName="list item", name="Schedule").click()
 
         # Periodic to settings
-        periodic = self.app.child(roleName="check box", name="Back Up Automatically")
+        periodic = self.app.child(roleName="switch", name="Back Up Automatically")
         self.assertFalse(periodic.checked)
         periodic.click()
         self.assertTrue(self.get_boolean("periodic"))
@@ -78,7 +74,7 @@ class PreferencesTest(BaseTest):
         table = self.refresh(table)
 
         def iter(x):
-            return x.roleName == "label" and not x.name.startswith("Add")
+            return x.roleName == "list item" and not x.name.startswith("Add")
 
         objs = table.findChildren(iter, showingOnly=False)
         return [x.name for x in objs]
@@ -89,7 +85,7 @@ class PreferencesTest(BaseTest):
     def assert_inclusion_table(self, widget, add_label, key):
         self.app.child(roleName="list item", name="Folders").click()
 
-        table = self.app.child(roleName="list", name=widget)
+        table = self.app.child(roleName="grouping", name=widget)
 
         user = GLib.get_user_name()
         home = GLib.get_home_dir()
